==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/d0c/road__widget_8h.js <==
var road__widget_8h =
[
    [ "BuildRoadDepotWidgets", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0", [
      [ "WID_BROD_CAPTION", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0a9df08aeb7b34ac60e0e474fc1704e62d", null ],
      [ "WID_BROD_DEPOT_NE", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0a04af45605a0ab1c848419a8c6ee14ee9", null ],
      [ "WID_BROD_DEPOT_SE", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0a00e5c845fd7149f8d1d3e9ff8bca73d4", null ],
      [ "WID_BROD_DEPOT_SW", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0aca68569678f256c7ce0b479344e109b9", null ],
      [ "WID_BROD_DEPOT_NW", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0a9ff8583e53cc6ba80b195553995ce920", null ]
    ] ],
    [ "BuildRoadStationWidgets", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36", [
      [ "WID_BROS_CAPTION", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36ac6b209cb6480aaeeb244f06934c8bbb1", null ],
      [ "WID_BROS_BACKGROUND", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a188e0b928516572059fabedc32e9b95d", null ],
      [ "WID_BROS_STATION_NE", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a9c3efb3aff9fc3d6233ad2ee47178f1b", null ],
      [ "WID_BROS_STATION_SE", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36ac153137b1520a7fe58987c1a47c06e5d", null ],
      [ "WID_BROS_STATION_SW", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a86dea40e8496096a0581bfa100833057", null ],
      [ "WID_BROS_STATION_NW", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36aef267c5eddec4d8ae2a6a99335843cc0", null ],
      [ "WID_BROS_STATION_X", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a93d5c0142dbcb369b113cdf8dc6de88f", null ],
      [ "WID_BROS_STATION_Y", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36af216ccc80ce82ca64a5e83c18054b30a", null ],
      [ "WID_BROS_LT_OFF", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36afa2d9550c30053caca621f9953441689", null ],
      [ "WID_BROS_LT_ON", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a1895a55f7c3c3e3c5ecbcd6d1ed1d333", null ],
      [ "WID_BROS_INFO", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a2ebb7999601144ab26949e64204cea8c", null ]
    ] ],
    [ "RoadToolbarWidgets", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebd", [
      [ "WID_ROT_ROAD_X", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebdaedfa94b58206d6bf3c49ace7f28ca899", null ],
      [ "WID_ROT_ROAD_Y", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda59dac7f4e84dc89fa3e4e261a41a6073", null ],
      [ "WID_ROT_AUTOROAD", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda6e4d70641289d769b5a735ac5a82949d", null ],
      [ "WID_ROT_DEMOLISH", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda80fe2bddcd173e1cb1596256d7fd828f", null ],
      [ "WID_ROT_DEPOT", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda231a42b609af16050236b4edc4d603ca", null ],
      [ "WID_ROT_BUS_STATION", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda195189fea160bca28d52252461aeccea", null ],
      [ "WID_ROT_TRUCK_STATION", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda95a3faa6e268b49987a6577286fb20e2", null ],
      [ "WID_ROT_ONE_WAY", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebdae745625343966380f32bc8e9834ababa", null ],
      [ "WID_ROT_BUILD_BRIDGE", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda0471aa4607d06842b723d8d932870b4b", null ],
      [ "WID_ROT_BUILD_TUNNEL", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda92e05ec5f6cd43dc6680018e6b97e207", null ],
      [ "WID_ROT_REMOVE", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebdab0d8dd11fe1f41f1a3ba2941af7f2cef", null ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/d0c/road__widget_8h.js <==
var road__widget_8h =
[
    [ "BuildRoadDepotWidgets", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0", [
      [ "WID_BROD_CAPTION", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0a9df08aeb7b34ac60e0e474fc1704e62d", null ],
      [ "WID_BROD_DEPOT_NE", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0a04af45605a0ab1c848419a8c6ee14ee9", null ],
      [ "WID_BROD_DEPOT_SE", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0a00e5c845fd7149f8d1d3e9ff8bca73d4", null ],
      [ "WID_BROD_DEPOT_SW", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0aca68569678f256c7ce0b479344e109b9", null ],
      [ "WID_BROD_DEPOT_NW", "d4/d0c/road__widget_8h.html#a85c21c6ef13df91aba54d0a6e2cb4af0a9ff8583e53cc6ba80b195553995ce920", null ]
    ] ],
    [ "BuildRoadStationWidgets", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36", [
      [ "WID_BROS_CAPTION", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36ac6b209cb6480aaeeb244f06934c8bbb1", null ],
      [ "WID_BROS_BACKGROUND", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a188e0b928516572059fabedc32e9b95d", null ],
      [ "WID_BROS_STATION_NE", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a9c3efb3aff9fc3d6233ad2ee47178f1b", null ],
      [ "WID_BROS_STATION_SE", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36ac153137b1520a7fe58987c1a47c06e5d", null ],
      [ "WID_BROS_STATION_SW", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a86dea40e8496096a0581bfa100833057", null ],
      [ "WID_BROS_STATION_NW", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36aef267c5eddec4d8ae2a6a99335843cc0", null ],
      [ "WID_BROS_STATION_X", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a93d5c0142dbcb369b113cdf8dc6de88f", null ],
      [ "WID_BROS_STATION_Y", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36af216ccc80ce82ca64a5e83c18054b30a", null ],
      [ "WID_BROS_LT_OFF", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36afa2d9550c30053caca621f9953441689", null ],
      [ "WID_BROS_LT_ON", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a1895a55f7c3c3e3c5ecbcd6d1ed1d333", null ],
      [ "WID_BROS_INFO", "d4/d0c/road__widget_8h.html#aed0b65c9985903ae17c1ee2a7ea49c36a2ebb7999601144ab26949e64204cea8c", null ]
    ] ],
    [ "RoadToolbarWidgets", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebd", [
      [ "WID_ROT_CAPTION", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda4041801b1275952bbcf480005455bcd9", null ],
      [ "WID_ROT_ROAD_X", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebdaedfa94b58206d6bf3c49ace7f28ca899", null ],
      [ "WID_ROT_ROAD_Y", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda59dac7f4e84dc89fa3e4e261a41a6073", null ],
      [ "WID_ROT_AUTOROAD", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda6e4d70641289d769b5a735ac5a82949d", null ],
      [ "WID_ROT_DEMOLISH", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda80fe2bddcd173e1cb1596256d7fd828f", null ],
      [ "WID_ROT_DEPOT", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda231a42b609af16050236b4edc4d603ca", null ],
      [ "WID_ROT_BUS_STATION", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda195189fea160bca28d52252461aeccea", null ],
      [ "WID_ROT_TRUCK_STATION", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda95a3faa6e268b49987a6577286fb20e2", null ],
      [ "WID_ROT_ONE_WAY", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebdae745625343966380f32bc8e9834ababa", null ],
      [ "WID_ROT_BUILD_BRIDGE", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda0471aa4607d06842b723d8d932870b4b", null ],
      [ "WID_ROT_BUILD_TUNNEL", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda92e05ec5f6cd43dc6680018e6b97e207", null ],
      [ "WID_ROT_REMOVE", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebdab0d8dd11fe1f41f1a3ba2941af7f2cef", null ],
      [ "WID_ROT_CONVERT_ROAD", "d4/d0c/road__widget_8h.html#aa483de17f0ace15b4a3880fa9253eebda9dc05180eca4d731d7ef10979b759cb6", null ]
    ] ]
];
